=======
History
=======


v0.0.2 (2018-12-24)
-------------------
- Bump version: 0.0.1 → 0.0.2   - finally tox works with all versions in
  PyCharm environment   - starter tests for type and constants.
- Bump version: 0.0.1 → 0.0.2.
- Refab:   - entry point rename. 
- Feat:   - python 3.4 compatible named tuples for library options   -
  starter constant   - tested. 
- Refab:   - some basic test to make 100% coverage.
- Chore:   - move interpreter version requirements from Pipfile into
  setup.py   - turn on live log for py.test   - return standard
  environment names in tox setup   - set interpreter location for 'py-
  charm' in tox setup   - fix python path passed in tox setup   - edit
  doc according to 2 previous items. 
- Wip: 


v0.0.1 (2018-12-21)
-------------------
- Bump version: 0.0.0 → 0.0.1   Project prepared for coding the tests.
  
- Chore:   - put into project current source to refab and test.
  
- Chore:   - changelog by git commits generation tool. [Konstantin
  Goncharov]
- Docs:   - short list what have been done to provide tooling.
  
- Chore:   - add make scripts for devpi   - setup docs generation with
  browser refresh on changes   - all make commands works. [Konstantin
  Goncharov]
- Feat:   - add primitive test   - satisfy flake8. [Konstantin
  Goncharov]
- Chore:   - return template dev deps. 
- Chore:   - install bumpversion dep   - move pipfile loca index example
  in main file   - add make script to generate requirements(_dev).txt.
  
- Chore:   - add devpi to make local repo builds   - describe how to add
  devpi   - provide files for run test in devpi environment. [Konstantin
  Goncharov]


v0.0.0 (2018-12-20)
-------------------
- Chore:   - add description how to create this scaffolding   - zeroed
  version. 
- Chore:   - initialize python envs and deps. 
- Chore:   - start from template. 
